# -*- coding: utf-8 -*-

import argparse
import os

from idatplot import utils as iu
from idatplot.vendors.extractor import hdf

# DEFAULT_SEP = ' # '
DEFAULT_SEP = '   '


def _load_esf(ep, sep = '\n'):
    with open(ep) as ef:
        quantities = [e.strip() for e in ef.read().split(sep)]
    return list(filter(None, quantities))


def extract(edf, quantities, eof, sep = DEFAULT_SEP):
    hdf.Exporter.exportAsText(hdf.PdrHDF(edf), 
            None, 
            quantities, 
            eof,
            separator = sep)


def cmdline_client(cffile, h5file, outdir, simple_format = False):

    def _cf_quantities(cf):
        """ if quantites are provided as an .esf file, the separtor is newline
        (1 quantitiy per line)"""

        cfq = cf['quantities']
        quantities = []
        if isinstance(cfq, str):
            quantities = _load_esf(cfq)
        else:
            quantities = cfq
        return quantities

    dfroot, _ = os.path.splitext(os.path.basename(h5file))

    if simple_format:
        # in this case *outdir* is actually the output file path
        extract(h5file, _load_esf(cffile), 
                outdir, 
                DEFAULT_SEP)
    else:
        cf = dict(iu.load_conf(cffile))
        for ecf in cf['extract']:
            ofpath = outdir + '/' + ecf['output'].format(dfroot)
            print('creating {}...'.format(ofpath))
            extract(h5file, _cf_quantities(ecf), 
                    ofpath, ecf.get('separator', DEFAULT_SEP))



def main():
    
    parser = argparse.ArgumentParser()
    parser.add_argument("-t", action='store_true', 
            help = "parse cffile as a simple 1 quantity per line txt file")
    parser.add_argument('hdf5file')
    parser.add_argument('cffile')
    parser.add_argument('outdir')
   
    args = parser.parse_args()
    cmdline_client(args.cffile, args.hdf5file, args.outdir, args.t)

if __name__ == '__main__':
    main()
