import urllib.request
import json
import argparse
import os.path
import sys
from server.lib import config
from server.lib import util

def read_quantities(filename):
    result = []
    with open(filename) as f:
        for line in f.readlines():
            result.append(line.strip())

    if(len(result) > 0):
        return result
    else:
        raise Exception('file not found')

def process(files, templates, output, yaml):
    data_files = files
    data_links = []
    quantities_file = templates
    quantities = []
    output_dir = None
    if quantities_file is not None:
        output_dir = output
        
    for f in data_files:
        util.create_file_link(f)
        data_links.append(os.path.basename(f))
        
    SERVICE_URL = f"http://localhost:{config.SERVER_PORT}{config.BASE_URL}/"
    if os.path.isfile(quantities_file):
        quantities = read_quantities(quantities_file)
    else:
        print("File listing quantities to extract is not valid")
        sys.exit()
    user_query = {'parameters': quantities,
                  'output_dir': output_dir,
                  'datatype': 'cli',
                  'files': data_links}
        

    req = urllib.request.Request(SERVICE_URL + "execute/extract")
    req.add_header("Content-type", 'application/json; charset=utf-8')
    jsondata = json.dumps(user_query)

    jsondataasbytes = jsondata.encode("utf-8")
    req.add_header("Content-length", len(jsondataasbytes))
    response = urllib.request.urlopen(req, jsondataasbytes)
    
    if yaml is not None:
        with open(yaml, 'r') as fp:
            user_query["yaml"] = fp.read()
        try :
            req = urllib.request.Request(SERVICE_URL + "execute/plot")
            req.add_header("Content-type", 'application/json; charset=utf-8')
            jsondata = json.dumps(user_query)

            jsondataasbytes = jsondata.encode("utf-8")
            req.add_header("Content-length", len(jsondataasbytes))
            response = urllib.request.urlopen(req, jsondataasbytes)
        except Exception as e:
            print(e)
        


    # result is a dict of result files and errors
    result = json.loads(response.read().decode("utf-8"))


def main():
    description = "Extract quantities from hdf files"
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument("-f", "--file",
                        help="path towards the HDF5 file")
    parser.add_argument("-t", "--template",
                        help="path towards the ASCII file with the list \
                             of quantities to extract")
    parser.add_argument("-o", "--output",
                        help="path and name of the ASCII output file \
                              to produce.")
    parser.add_argument("-y", "--yaml",
                        help="optional : path towards a yaml \
                              file to generate plots.")

    args = vars(parser.parse_args())

    if args['file'] is None:
        print("Error : the path to hdf5 file is missing.")
        sys.exit()

    if args['template'] is None:
        print("Error : the list of quantities to extract is missing.")
        sys.exit()

    if args['output'] is None:
        print("Error : the path to extracted data is missing.")
        sys.exit()
        
    process([   args['file']], 
                args['template'], 
                args["output"], 
                args["yaml"])



if __name__ == "__main__":
    main()
